@@ -7,9 +7,9 @@ from unittest import mock
 
 import pytest  # type: ignore
 
-from helpers import app_name, run_pipx_cli, unwrap_log_text
+from helpers import app_name, run_pipx_cli, skip_if_windows, unwrap_log_text
 from package_info import PKG
-from pipx import constants
+from pipx import paths, shared_libs
 
 TEST_DATA_PATH = "./testdata/test_package_specifier"
 
@@ -58,6 +58,15 @@ def test_install_easy_multiple_packages(capsys, pipx_temp_env, caplog):
     )
 
 
+@pytest.mark.parametrize(
+    "package_name, package_spec",
+    [("pycowsay", "pycowsay"), ("black", PKG["black"]["spec"])],
+)
+@skip_if_windows
+def test_install_easy_packages_globally(capsys, pipx_temp_env, caplog, package_name, package_spec):
+    install_packages(capsys, pipx_temp_env, caplog, [package_spec], [package_name])
+
+
 @pytest.mark.parametrize(
     "package_name, package_spec",
     [
@@ -165,12 +174,10 @@ def test_path_warning(pipx_temp_env, capsys, monkeypatch, caplog):
     assert "is not on your PATH environment variable" in unwrap_log_text(caplog.text)
 
 
+@skip_if_windows
 def test_existing_symlink_points_to_existing_wrong_location_warning(pipx_temp_env, caplog, capsys):
-    if sys.platform.startswith("win"):
-        pytest.skip("pipx does not use symlinks on Windows")
-
-    constants.LOCAL_BIN_DIR.mkdir(exist_ok=True, parents=True)
-    (constants.LOCAL_BIN_DIR / "pycowsay").symlink_to(os.devnull)
+    paths.ctx.bin_dir.mkdir(exist_ok=True, parents=True)
+    (paths.ctx.bin_dir / "pycowsay").symlink_to(os.devnull)
     assert not run_pipx_cli(["install", "pycowsay"])
     captured = capsys.readouterr()
     assert "File exists at" in unwrap_log_text(caplog.text)
@@ -180,24 +187,20 @@ def test_existing_symlink_points_to_existing_wrong_location_warning(pipx_temp_en
     assert "is not on your PATH environment variable" not in captured.err
 
 
+@skip_if_windows
 def test_existing_man_page_symlink_points_to_existing_wrong_location_warning(pipx_temp_env, caplog, capsys):
-    if sys.platform.startswith("win"):
-        pytest.skip("pipx does not use symlinks on Windows")
-
-    (constants.LOCAL_MAN_DIR / "man6").mkdir(exist_ok=True, parents=True)
-    (constants.LOCAL_MAN_DIR / "man6" / "pycowsay.6").symlink_to(os.devnull)
+    (paths.ctx.man_dir / "man6").mkdir(exist_ok=True, parents=True)
+    (paths.ctx.man_dir / "man6" / "pycowsay.6").symlink_to(os.devnull)
     assert not run_pipx_cli(["install", "pycowsay"])
     captured = capsys.readouterr()
     assert "File exists at" in unwrap_log_text(caplog.text)
     assert "symlink missing or pointing to unexpected location" in captured.out
 
 
+@skip_if_windows
 def test_existing_symlink_points_to_nothing(pipx_temp_env, capsys):
-    if sys.platform.startswith("win"):
-        pytest.skip("pipx does not use symlinks on Windows")
-
-    constants.LOCAL_BIN_DIR.mkdir(exist_ok=True, parents=True)
-    (constants.LOCAL_BIN_DIR / "pycowsay").symlink_to("/asdf/jkl")
+    paths.ctx.bin_dir.mkdir(exist_ok=True, parents=True)
+    (paths.ctx.bin_dir / "pycowsay").symlink_to("/asdf/jkl")
     assert not run_pipx_cli(["install", "pycowsay"])
     captured = capsys.readouterr()
     # pipx should realize the symlink points to nothing and replace it,
@@ -205,12 +208,10 @@ def test_existing_symlink_points_to_nothing(pipx_temp_env, capsys):
     assert "symlink missing or pointing to unexpected location" not in captured.out
 
 
+@skip_if_windows
 def test_existing_man_page_symlink_points_to_nothing(pipx_temp_env, capsys):
-    if sys.platform.startswith("win"):
-        pytest.skip("pipx does not use symlinks on Windows")
-
-    (constants.LOCAL_MAN_DIR / "man6").mkdir(exist_ok=True, parents=True)
-    (constants.LOCAL_MAN_DIR / "man6" / "pycowsay.6").symlink_to("/asdf/jkl")
+    (paths.ctx.man_dir / "man6").mkdir(exist_ok=True, parents=True)
+    (paths.ctx.man_dir / "man6" / "pycowsay.6").symlink_to("/asdf/jkl")
     assert not run_pipx_cli(["install", "pycowsay"])
     captured = capsys.readouterr()
     # pipx should realize the symlink points to nothing and replace it,
@@ -218,6 +219,21 @@ def test_existing_man_page_symlink_points_to_nothing(pipx_temp_env, capsys):
     assert "symlink missing or pointing to unexpected location" not in captured.out
 
 
+def test_pip_args_forwarded_to_shared_libs(pipx_ultra_temp_env, capsys, caplog):
+    # strategy:
+    # 1. start from an empty env to ensure the next command would trigger a shared lib update
+    assert shared_libs.shared_libs.needs_upgrade
+    # 2. install any package with --no-index
+    # and check that the shared library update phase fails
+    return_code = run_pipx_cli(["install", "--verbose", "--pip-args=--no-index", "pycowsay"])
+    assert "Upgrading shared libraries in" in caplog.text
+
+    captured = capsys.readouterr()
+    assert return_code != 0
+    assert "ERROR: Could not find a version that satisfies the requirement pip" in captured.err
+    assert "Failed to upgrade shared libraries" in caplog.text
+
+
 def test_pip_args_forwarded_to_package_name_determination(pipx_temp_env, capsys):
     assert run_pipx_cli(
         [
@@ -263,15 +279,15 @@ def test_install_suffix(pipx_temp_env, capsys):
     name_b = app_name(f"{name}{suffix}")
     assert f"- {name_b}" in captured.out
 
-    assert (constants.LOCAL_BIN_DIR / name_a).exists()
-    assert (constants.LOCAL_BIN_DIR / name_b).exists()
+    assert (paths.ctx.bin_dir / name_a).exists()
+    assert (paths.ctx.bin_dir / name_b).exists()
 
 
 def test_man_page_install(pipx_temp_env, capsys):
     assert not run_pipx_cli(["install", "pycowsay"])
     captured = capsys.readouterr()
     assert f"- {Path('man6/pycowsay.6')}" in captured.out
-    assert (constants.LOCAL_MAN_DIR / "man6" / "pycowsay.6").exists()
+    assert (paths.ctx.man_dir / "man6" / "pycowsay.6").exists()
 
 
 def test_install_pip_failure(pipx_temp_env, capsys):
@@ -339,7 +355,9 @@ def test_passed_python_and_force_flag_warning(pipx_temp_env, capsys):
     assert "--python is ignored when --force is passed." not in captured.out
 
 
-def test_passed_python_not_executable(pipx_temp_env, capsys):
-    assert run_pipx_cli(["install", "--python", "py_not_real", "pycowsay"])
-    captured = capsys.readouterr()
-    assert "No executable for the provided Python version" in captured.out
+def test_install_run_in_separate_directory(caplog, capsys, pipx_temp_env, monkeypatch, tmp_path):
+    monkeypatch.chdir(tmp_path)
+    f = Path("argparse.py")
+    f.touch()
+
+    install_packages(capsys, pipx_temp_env, caplog, ["pycowsay"], ["pycowsay"])
