@@ -1,4 +1,4 @@
-from helpers import run_pipx_cli
+from helpers import run_pipx_cli, skip_if_windows
 from package_info import PKG
 
 
@@ -13,11 +13,21 @@ def test_uninject_simple(pipx_temp_env, capsys):
     assert "black" not in captured.out
 
 
+@skip_if_windows
+def test_uninject_simple_global(pipx_temp_env, capsys):
+    assert not run_pipx_cli(["--global", "install", "pycowsay"])
+    assert not run_pipx_cli(["--global", "inject", "pycowsay", PKG["black"]["spec"]])
+    assert not run_pipx_cli(["--global", "uninject", "pycowsay", "black"])
+    captured = capsys.readouterr()
+    assert "Uninjected package black" in captured.out
+    assert not run_pipx_cli(["--global", "list", "--include-injected"])
+    captured = capsys.readouterr()
+    assert "black" not in captured.out
+
+
 def test_uninject_with_include_apps(pipx_temp_env, capsys, caplog):
     assert not run_pipx_cli(["install", "pycowsay"])
-    assert not run_pipx_cli(
-        ["inject", "pycowsay", PKG["black"]["spec"], "--include-deps", "--include-apps"]
-    )
+    assert not run_pipx_cli(["inject", "pycowsay", PKG["black"]["spec"], "--include-deps", "--include-apps"])
     assert not run_pipx_cli(["uninject", "pycowsay", "black", "--verbose"])
     assert "removed file" in caplog.text
 
@@ -25,9 +35,7 @@ def test_uninject_with_include_apps(pipx_temp_env, capsys, caplog):
 def test_uninject_leave_deps(pipx_temp_env, capsys, caplog):
     assert not run_pipx_cli(["install", "pycowsay"])
     assert not run_pipx_cli(["inject", "pycowsay", PKG["black"]["spec"]])
-    assert not run_pipx_cli(
-        ["uninject", "pycowsay", "black", "--leave-deps", "--verbose"]
-    )
+    assert not run_pipx_cli(["uninject", "pycowsay", "black", "--leave-deps", "--verbose"])
     captured = capsys.readouterr()
     assert "Uninjected package black from venv pycowsay" in captured.out
     assert "Dependencies of uninstalled package:" not in caplog.text
